==> retgoo_sdk-0.0.4.tar.gz: lib/widgets/retgoo_app.dart <==
import 'package:firebase_core/firebase_core.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_localizations/flutter_localizations.dart';
import 'package:provider/provider.dart';
import 'package:retgoo_sdk/forms/forms.dart';
import 'package:retgoo_sdk/lang/default_translation.dart';
import 'package:retgoo_sdk/lang/translation.dart';
import 'package:retgoo_sdk/pages/google_login_page.dart';
import 'package:retgoo_sdk/pages/home_page.dart';
import 'package:retgoo_sdk/pages/user_login_dashboard.dart';
import 'package:retgoo_sdk/protocol/api.dart';
import 'package:retgoo_sdk/providers/authentication_provider.dart';
import 'package:retgoo_sdk/providers/notification_provider.dart';
import 'package:retgoo_sdk/providers/shortcut_provider.dart';
import 'package:retgoo_sdk/retgoo_sdk.dart';
import 'package:retgoo_sdk/widgets/retgoo_server.dart';

class RetGooApp extends StatelessWidget {
  final String title;
  final Map<String, UserTaskBuilder> userTasks;
  final String serverHost;
  final ThemeData theme;
  final Map<String, Map<Language, String>> translations;
  final bool ignoreFlowButton;
  final double pixelRatio;

  static Future<void> run({
    String title = 'RetGoo Portal',
    Map<String, UserTaskBuilder> userTasks,
    String serverHost,
    ThemeData theme,
    Map<String, Map<Language, String>> translations,
    bool ignoreFlowButton = false,
    double pixelRatio = 1.0,
  }) async {
    WidgetsFlutterBinding.ensureInitialized();
    GestureBinding.instance.resamplingEnabled = true;
    await Firebase.initializeApp();

    runApp(RetGooApp._(
      title: title,
      pixelRatio: pixelRatio,
      ignoreFlowButton: ignoreFlowButton,
      serverHost: serverHost,
      theme: theme,
      translations: translations,
      userTasks: userTasks,
    ));
  }

  const RetGooApp._({
    Key key,
    this.title = 'RetGoo Portal',
    this.userTasks,
    this.serverHost,
    this.theme,
    this.translations,
    this.ignoreFlowButton = false,
    this.pixelRatio = 1.0,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    registeredUserTasks = userTasks;
    baseURL = serverHost;
    isIgnoreFlowButton = ignoreFlowButton;

    resetTranslation();
    setTranslation(defaultTranslations);

    if (translations != null) {
      setTranslation(translations);
    }

    return AnnotatedRegion(
      value: SystemUiOverlayStyle.dark.copyWith(
        statusBarColor: Colors.transparent,
      ),
      child: ChangeNotifierProvider(
        create: (context) => AuthenticationProvider(),
        child: FractionallySizedBox(
          widthFactor: 1.0 / pixelRatio,
          heightFactor: 1.0 / pixelRatio,
          child: Transform.scale(
            scale: pixelRatio,
            child: MaterialApp(
              title: title,
              theme: theme ??
                  ThemeData(
                    primarySwatch: Colors.indigo,
                    primaryColor: Colors.indigo.shade900,
                    inputDecorationTheme: InputDecorationTheme(
                      border: OutlineInputBorder(),
                    ),
                    cardTheme: CardTheme(
                      clipBehavior: Clip.antiAlias,
                      elevation: 8.0,
                      shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(8.0),
                      ),
                      shadowColor: Colors.black.withOpacity(0.5),
                    ),
                    visualDensity: VisualDensity.adaptivePlatformDensity,
                  ),
              routes: {
                "/": (context) => HomePage(),
              },
              builder: (context, navigator) {
                return Selector<AuthenticationProvider, AuthenticationState>(
                  selector: (context, provider) => provider.state,
                  builder: (context, state, child) {
                    if (state == AuthenticationState.initializing) {
                      return Scaffold(
                        body: Center(
                          child: CircularProgressIndicator(),
                        ),
                      );
                    }

                    if (state == AuthenticationState.unautenticated) {
                      return Navigator(
                        pages: [
                          MaterialPage(
                            child: GoogleLoginPage(),
                          ),
                        ],
                        onPopPage: (route, result) => route.didPop(result),
                      );
                    }

                    if (state == AuthenticationState.dashboard) {
                      return Navigator(
                        pages: [
                          MaterialPage(
                            child: UserLoginDashboard(),
                          ),
                        ],
                        onPopPage: (route, result) => route.didPop(result),
                      );
                    }

                    return MultiProvider(
                      providers: [
                        ChangeNotifierProvider(
                          create: (context) => ShortcutProvider(),
                        ),
                        ChangeNotifierProvider(
                          create: (context) => NotificationProvider(),
                        )
                      ],
                      child: RetGooServer(
                        child: child,
                      ),
                    );
                  },
                  child: navigator,
                );
              },
              debugShowCheckedModeBanner: false,
              localizationsDelegates: [
                LocalizationDelegate.delegate,
                GlobalMaterialLocalizations.delegate,
                GlobalWidgetsLocalizations.delegate,
                GlobalCupertinoLocalizations.delegate,
              ],
              supportedLocales: [
                const Locale('id', 'ID'),
                const Locale('en', 'US'),
              ],
            ),
          ),
        ),
      ),
    );
  }
}

==> retgoo_sdk-0.0.7.tar.gz: lib/widgets/retgoo_app.dart <==
import 'package:firebase_core/firebase_core.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_localizations/flutter_localizations.dart';
import 'package:provider/provider.dart';
import 'package:retgoo_sdk/forms/forms.dart';
import 'package:retgoo_sdk/lang/default_translation.dart';
import 'package:retgoo_sdk/lang/translation.dart';
import 'package:retgoo_sdk/pages/home/splash_screen_page.dart';
import 'package:retgoo_sdk/pages/login/login_google.dart';
import 'package:retgoo_sdk/pages/home/home_page.dart';
import 'package:retgoo_sdk/pages/login/login_user_switch.dart';
import 'package:retgoo_sdk/protocol/api.dart';
import 'package:retgoo_sdk/providers/authentication_provider.dart';
import 'package:retgoo_sdk/providers/notification_provider.dart';
import 'package:retgoo_sdk/providers/shortcut_provider.dart';
import 'package:retgoo_sdk/retgoo_sdk.dart';
import 'package:retgoo_sdk/widgets/retgoo_server.dart';
import 'package:timeago/timeago.dart' as timeago;

final navigatorKey = GlobalKey<NavigatorState>();

class RetGooApp extends StatelessWidget {
  final String title;
  final Map<String, UserTaskBuilder> userTasks;
  final String serverHost;
  final ThemeData theme;
  final Map<String, Map<Language, String>> translations;
  final bool ignoreFlowButton;
  final double pixelRatio;

  static Future<void> run({
    String title = 'RetGoo Portal',
    Map<String, UserTaskBuilder> userTasks,
    String serverHost,
    ThemeData theme,
    Map<String, Map<Language, String>> translations,
    bool ignoreFlowButton = false,
    double pixelRatio = 1.0,
  }) async {
    WidgetsFlutterBinding.ensureInitialized();
    GestureBinding.instance.resamplingEnabled = true;
    //initializeDateFormatting("id");
    timeago.setLocaleMessages("id", timeago.IdMessages());

    await Firebase.initializeApp();

    runApp(RetGooApp._(
      title: title,
      pixelRatio: pixelRatio,
      ignoreFlowButton: ignoreFlowButton,
      serverHost: serverHost,
      theme: theme,
      translations: translations,
      userTasks: userTasks,
    ));
  }

  const RetGooApp._({
    Key key,
    this.title = 'RetGoo Portal',
    this.userTasks,
    this.serverHost,
    this.theme,
    this.translations,
    this.ignoreFlowButton = false,
    this.pixelRatio = 1.0,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    registeredUserTasks = userTasks;
    baseURL = serverHost;
    isIgnoreFlowButton = ignoreFlowButton;

    resetTranslation();
    setTranslation(defaultTranslations);

    if (translations != null) {
      setTranslation(translations);
    }

    return AnnotatedRegion(
      value: SystemUiOverlayStyle.dark.copyWith(
        statusBarColor: Colors.transparent,
      ),
      child: ChangeNotifierProvider(
        create: (context) => AuthenticationProvider(),
        child: FractionallySizedBox(
          widthFactor: 1.0 / pixelRatio,
          heightFactor: 1.0 / pixelRatio,
          child: Transform.scale(
            scale: pixelRatio,
            child: MaterialApp(
              title: title,
              navigatorKey: navigatorKey,
              theme: theme ??
                  ThemeData(
                    primarySwatch: Colors.indigo,
                    primaryColor: Colors.indigo.shade900,
                    inputDecorationTheme: InputDecorationTheme(
                      border: OutlineInputBorder(),
                    ),
                    cardTheme: CardTheme(
                      clipBehavior: Clip.antiAlias,
                      elevation: 8.0,
                      shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(8.0),
                      ),
                      shadowColor: Colors.black.withOpacity(0.5),
                    ),
                    visualDensity: VisualDensity.adaptivePlatformDensity,
                  ),
              routes: {
                "/": (context) => HomePage(),
              },
              builder: (context, navigator) {
                return Selector<AuthenticationProvider, AuthenticationState>(
                  selector: (context, provider) => provider.state,
                  builder: (context, state, child) {
                    if (state == AuthenticationState.initializing) {
                      return SplashScreenPage();
                    }

                    if (state == AuthenticationState.unautenticated) {
                      return Navigator(
                        pages: [
                          MaterialPage(
                            child: LoginPage(),
                          ),
                        ],
                        onPopPage: (route, result) => route.didPop(result),
                      );
                    }

                    if (state == AuthenticationState.dashboard) {
                      return Navigator(
                        pages: [
                          MaterialPage(
                            child: UserAuthSelector(),
                          ),
                        ],
                        onPopPage: (route, result) => route.didPop(result),
                      );
                    }

                    return MultiProvider(
                      providers: [
                        ChangeNotifierProvider(
                          create: (context) => ShortcutProvider(),
                        ),
                        ChangeNotifierProvider(
                          create: (context) => NotificationProvider(),
                        )
                      ],
                      child: RetGooServer(
                        child: child,
                      ),
                    );
                  },
                  child: navigator,
                );
              },
              debugShowCheckedModeBanner: false,
              localizationsDelegates: [
                LocalizationDelegate.delegate,
                GlobalMaterialLocalizations.delegate,
                GlobalWidgetsLocalizations.delegate,
                GlobalCupertinoLocalizations.delegate,
              ],
              supportedLocales: [
                const Locale('id', 'ID'),
                const Locale('en', 'US'),
              ],
            ),
          ),
        ),
      ),
    );
  }
}
